# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`helm`](#helm): A module to install Helm, the Kubernetes package manager.
* [`helm::params`](#helmparams): This module installs Helm, the Kubernetes package manager.

#### Private Classes

* `helm::account_config`: helm::account_config
* `helm::binary`: helm::binary
* `helm::config`: helm::config

### Defined types

* [`helm::chart`](#helmchart): Manages the deployment of helm charts.
* [`helm::chart_update`](#helmchart_update): Update the deployed Helm charts.
* [`helm::create`](#helmcreate): Creates a new Helm chart.
* [`helm::helm_init`](#helmhelm_init): Deploys the Tiller pod and initializes the Helm client.
* [`helm::package`](#helmpackage): Packages a chart directory ino a chart archive..
* [`helm::repo`](#helmrepo): Adds a Helm repository.
* [`helm::repo_update`](#helmrepo_update): Updates all of the Helm repositories.

### Functions

* [`helm_chart_update_flags`](#helm_chart_update_flags): Transforms a hash into a string of helm install chart flags
* [`helm_create_flags`](#helm_create_flags): Transforms a hash into a string of helm create flags
* [`helm_delete_flags`](#helm_delete_flags): Transforms a hash into a string of helm delete flags
* [`helm_init_flags`](#helm_init_flags): Transforms a hash into a string of helm init flags
* [`helm_install_flags`](#helm_install_flags): Transforms a hash into a string of helm install chart flags
* [`helm_ls_flags`](#helm_ls_flags): Transforms a hash into a string of helm ls flags
* [`helm_package_flags`](#helm_package_flags): Transforms a hash into a string of helm package flags
* [`helm_repo_add_flags`](#helm_repo_add_flags): Transforms a hash into a string of helm repo add flags
* [`helm_repo_remove_flags`](#helm_repo_remove_flags): Transforms a hash into a string of helm repo remove flags
* [`helm_repo_update_flags`](#helm_repo_update_flags): Transforms a hash into a string of helm repo update flags

### Plans

* [`helm::provision_cluster`](#helmprovision_cluster): Provisions machines
* [`helm::puppetserver_setup`](#helmpuppetserver_setup): Provisions machines

## Classes

### <a name="helm"></a>`helm`

A module to install Helm, the Kubernetes package manager.

#### Parameters

The following parameters are available in the `helm` class:

* [`canary_image`](#canary_image)
* [`client_only`](#client_only)
* [`debug`](#debug)
* [`dry_run`](#dry_run)
* [`env`](#env)
* [`home`](#home)
* [`host`](#host)
* [`init`](#init)
* [`install_path`](#install_path)
* [`kube_context`](#kube_context)
* [`local_repo_url`](#local_repo_url)
* [`net_host`](#net_host)
* [`node_selectors`](#node_selectors)
* [`overrides`](#overrides)
* [`path`](#path)
* [`proxy`](#proxy)
* [`service_account`](#service_account)
* [`skip_refresh`](#skip_refresh)
* [`stable_repo_url`](#stable_repo_url)
* [`tiller_image`](#tiller_image)
* [`tiller_image_pull_secrets`](#tiller_image_pull_secrets)
* [`tiller_namespaces`](#tiller_namespaces)
* [`tiller_tls`](#tiller_tls)
* [`tiller_tls_cert`](#tiller_tls_cert)
* [`tiller_tls_key`](#tiller_tls_key)
* [`tiller_tls_verify`](#tiller_tls_verify)
* [`tls_ca_cert`](#tls_ca_cert)
* [`upgrade`](#upgrade)
* [`version`](#version)
* [`archive_baseurl`](#archive_baseurl)

##### <a name="canary_image"></a>`canary_image`

Data type: `Boolean`

Use the helm canary image for the default init of helm.
Defaults to false

Default value: `$helm::params::canary_image`

##### <a name="client_only"></a>`client_only`

Data type: `Boolean`

Make the default init install the client only.
Defaults to false

Default value: `$helm::params::client_only`

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Set output logging to debug for the default init.
Defaults to false

Default value: `$helm::params::debug`

##### <a name="dry_run"></a>`dry_run`

Data type: `Boolean`

Make the default init run in dry-run mode.
Defaults to false

Default value: `$helm::params::dry_run`

##### <a name="env"></a>`env`

Data type: `Array`

Environment variables to specify the location of configruation files, or any other custom variables required for helm to run.
Defaults to [ 'HOME=/root', 'KUBECONFIG=/root/admin.conf']

Default value: `$helm::params::env`

##### <a name="home"></a>`home`

Data type: `Optional[String]`

Set the HELM_HOME variable for the default init.
Defaults to undef

Default value: `$helm::params::home`

##### <a name="host"></a>`host`

Data type: `Optional[String]`

Specify the HELM_HOST for the default init.
Defaults to undef

Default value: `$helm::params::host`

##### <a name="init"></a>`init`

Data type: `Boolean`

Determines the behaviour of the config function. Setting to true will init the cluster and install tiller.
False will install Helm in client only mode.
Defaults to true

Default value: `$helm::params::init`

##### <a name="install_path"></a>`install_path`

Data type: `String`

The path to extract helm binary to.
Defaults to '/usr/bin'

Default value: `$helm::params::install_path`

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

Specify the kube_context for the default init.
Defaults to undef

Default value: `$helm::params::kube_context`

##### <a name="local_repo_url"></a>`local_repo_url`

Data type: `Optional[String]`

Specify the local_repo_url for the default init.
Defaults to undef

Default value: `$helm::params::local_repo_url`

##### <a name="net_host"></a>`net_host`

Data type: `Optional[Boolean]`

Enable net_host mode for the default init.
Defaults to false

Default value: `$helm::params::net_host`

##### <a name="node_selectors"></a>`node_selectors`

Data type: `Optional[String]`

Specify node selectors for the helm init on the default init.
Defaults to undef

Default value: `$helm::params::node_selectors`

##### <a name="overrides"></a>`overrides`

Data type: `Optional[Array]`

Specify override parameters for the default init.
Defaults to undef

Default value: `$helm::params::overrides`

##### <a name="path"></a>`path`

Data type: `Array`

The PATH variable used for exec types.
Defaults to ['/bin','/usr/bin']

Default value: `$helm::params::path`

##### <a name="proxy"></a>`proxy`

Data type: `Optional[String]`

Specify an internet proxy if necessary.
Defaults to undef

Default value: `$helm::params::proxy`

##### <a name="service_account"></a>`service_account`

Data type: `String`

The service account for tiller
Defaults to 'tiller'

Default value: `$helm::params::service_account`

##### <a name="skip_refresh"></a>`skip_refresh`

Data type: `Boolean`

Enable skip refresh mode for the default init.
Defaults to false

Default value: `$helm::params::skip_refresh`

##### <a name="stable_repo_url"></a>`stable_repo_url`

Data type: `Optional[String]`

Specify the stable repo url for the default init.
Defaults to undef

Default value: `$helm::params::stable_repo_url`

##### <a name="tiller_image"></a>`tiller_image`

Data type: `Optional[String]`

Specify the image for the tiller install in the default init.
Defaults to undef

Default value: `$helm::params::tiller_image`

##### <a name="tiller_image_pull_secrets"></a>`tiller_image_pull_secrets`

Data type: `Optional[Array[String]]`

Optionnaly put imagePullSecret(s) in tiller's serviceaccount.

Default value: `$helm::params::tiller_image_pull_secrets`

##### <a name="tiller_namespaces"></a>`tiller_namespaces`

Data type: `Array[String]`

Array of namespaces in which to install tiller
Defaults to ['kube-system']

Default value: `$helm::params::tiller_namespaces`

##### <a name="tiller_tls"></a>`tiller_tls`

Data type: `Boolean`

Enable TLS for tiller in the default init.
Defaults to false

Default value: `$helm::params::tiller_tls`

##### <a name="tiller_tls_cert"></a>`tiller_tls_cert`

Data type: `Optional[String]`

Specify a TLS cert for tiller in the default init.
Defaults to undef

Default value: `$helm::params::tiller_tls_cert`

##### <a name="tiller_tls_key"></a>`tiller_tls_key`

Data type: `Optional[String]`

Specify a TLS key for tiller in the default init.
Defaults to undef

Default value: `$helm::params::tiller_tls_key`

##### <a name="tiller_tls_verify"></a>`tiller_tls_verify`

Data type: `Boolean`

Enable TLS verification for tiller in the default init.
Defaults to undef

Default value: `$helm::params::tiller_tls_verify`

##### <a name="tls_ca_cert"></a>`tls_ca_cert`

Data type: `Optional[String]`

Specify a TLS CA certificate for tiller in the default init.
Defaults to undef

Default value: `$helm::params::tls_ca_cert`

##### <a name="upgrade"></a>`upgrade`

Data type: `Boolean`

Whether to upgrade tiller in the default init.
Defaults to false

Default value: `$helm::params::upgrade`

##### <a name="version"></a>`version`

Data type: `String`

The version of helm to install.
Defaults to 2.5.1

Default value: `$helm::params::version`

##### <a name="archive_baseurl"></a>`archive_baseurl`

Data type: `String`

The base URL for downloading the helm archive, must contain file helm-v${version}-linux-${arch}.tar.gz
Defaults to https://kubernetes-helm.storage.googleapis.com
URLs supported by puppet/archive module will work, e.g. puppet:///modules/helm_files

Default value: `$helm::params::archive_baseurl`

### <a name="helmparams"></a>`helm::params`

This module installs Helm, the Kubernetes package manager.

## Defined types

### <a name="helmchart"></a>`helm::chart`

Defined Type helm::chart

#### Parameters

The following parameters are available in the `helm::chart` defined type:

* [`ensure`](#ensure)
* [`ca_file`](#ca_file)
* [`cert_file`](#cert_file)
* [`debug`](#debug)
* [`devel`](#devel)
* [`dry_run`](#dry_run)
* [`env`](#env)
* [`key_file`](#key_file)
* [`key_ring`](#key_ring)
* [`home`](#home)
* [`host`](#host)
* [`kube_context`](#kube_context)
* [`name_template`](#name_template)
* [`no_hooks`](#no_hooks)
* [`path`](#path)
* [`purge`](#purge)
* [`release_name`](#release_name)
* [`replace`](#replace)
* [`repo`](#repo)
* [`set`](#set)
* [`timeout`](#timeout)
* [`tiller_namespace``](#tiller_namespace`)
* [`tls`](#tls)
* [`tls_ca_cert`](#tls_ca_cert)
* [`tls_cert`](#tls_cert)
* [`tls_key``](#tls_key`)
* [`tls_verify`](#tls_verify)
* [`values`](#values)
* [`verify`](#verify)
* [`version`](#version)
* [`wait`](#wait)
* [`chart`](#chart)
* [`namespace`](#namespace)
* [`tiller_namespace`](#tiller_namespace)
* [`tls_key`](#tls_key)

##### <a name="ensure"></a>`ensure`

Data type: `String`

Specifies whether a chart is deployed.

Default value: `present`

##### <a name="ca_file"></a>`ca_file`

Data type: `Optional[String]`

Verifies the certificates of the HTTPS-enabled servers using the CA bundle.

Default value: ``undef``

##### <a name="cert_file"></a>`cert_file`

Data type: `Optional[String]`

Identifies the HTTPS client using this SSL certificate file.

Default value: ``undef``

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable verbose output.
Values `true`, `false`.

Default value: ``false``

##### <a name="devel"></a>`devel`

Data type: `Boolean`

Specifies whether to use development versions.
Values `true`, `false`.

Default value: ``false``

##### <a name="dry_run"></a>`dry_run`

Data type: `Boolean`

Specifies whether to simulate an installation or delete a deployment.
Values `true`, `false`.

Default value: ``false``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables for Helm to connect to the kubernetes cluster.

Default value: ``undef``

##### <a name="key_file"></a>`key_file`

Data type: `Optional[String]`

Identifies the HTTPS client using thie SSL key file.

Default value: ``undef``

##### <a name="key_ring"></a>`key_ring`

Data type: `Optional[String]`

Location of the public keys that are used for verification.

Default value: ``undef``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

Location of your Helm config. This value overrides `$HELM_HOME`.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

Address of Tiller. This value overrides `$HELM_HOST`.

Default value: ``undef``

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

Name of the kubeconfig context.

Default value: ``undef``

##### <a name="name_template"></a>`name_template`

Data type: `Optional[String]`

The template used to name the release.

Default value: ``undef``

##### <a name="no_hooks"></a>`no_hooks`

Data type: `Boolean`

Specifies whether to prevent hooks running during the installation.
Values `true`, `false`.

Default value: ``false``

##### <a name="path"></a>`path`

Data type: `Optional[Array]`

The PATH variable used for exec types.

Default value: ``undef``

##### <a name="purge"></a>`purge`

Data type: `Boolean`

Specifies whether to remove the release from the store, and make its name available for later use.
Values `true`, `false`.

Default value: ``true``

##### <a name="release_name"></a>`release_name`

Data type: `Optional[String]`

**Required.** The release name.

Default value: ``undef``

##### <a name="replace"></a>`replace`

Data type: `Boolean`

Reuse the release name.

Default value: ``false``

##### <a name="repo"></a>`repo`

Data type: `Optional[String]`

The repository URL for a requested chart.

Default value: ``undef``

##### <a name="set"></a>`set`

Data type: `Optional[Array]`

The set array of values for the `helm create` command.

Default value: `[]`

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer]`

The timeout in seconds to wait for a Kubernetes operation.

Default value: ``undef``

##### <a name="tiller_namespace`"></a>`tiller_namespace``

The Tiller namespace.

##### <a name="tls"></a>`tls`

Data type: `Boolean`

Specifies whether to enable TLS.
Values `true`, `false`.

Default value: ``false``

##### <a name="tls_ca_cert"></a>`tls_ca_cert`

Data type: `Optional[String]`

The path to TLS CA certificate file.

Default value: ``undef``

##### <a name="tls_cert"></a>`tls_cert`

Data type: `Optional[String]`

The path to TLS certificate file.

Default value: ``undef``

##### <a name="tls_key`"></a>`tls_key``

The path to TLS key file.

##### <a name="tls_verify"></a>`tls_verify`

Data type: `Boolean`

Enable TLS for request and verify remote.

Default value: ``false``

##### <a name="values"></a>`values`

Data type: `Optional[Array]`

Specify values from a YAML file. Multiple values in an array are accepted.

Default value: `[]`

##### <a name="verify"></a>`verify`

Data type: `Boolean`

Specifies whether to verify the package before installing it.
Values `true`, `false`.

Default value: ``false``

##### <a name="version"></a>`version`

Data type: `Optional[String]`

Specify the version of the chart to install. `undef` installs the latest version.

Default value: ``undef``

##### <a name="wait"></a>`wait`

Data type: `Boolean`

Before marking the release as successful, specify whether to wait until all the pods, PVCs, services, and the minimum number of deployment pods are in a ready state. The `timeout` value determines the duration.
Values `true`, `false`.

Default value: ``false``

##### <a name="chart"></a>`chart`

Data type: `Optional[String]`

The file system location of the package.

Default value: ``undef``

##### <a name="namespace"></a>`namespace`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `Optional[String]`



Default value: `'kube-system'`

##### <a name="tls_key"></a>`tls_key`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="helmchart_update"></a>`helm::chart_update`

Defined Type helm::chart::update

#### Parameters

The following parameters are available in the `helm::chart_update` defined type:

* [`ensure`](#ensure)
* [`ca_file`](#ca_file)
* [`cert_file`](#cert_file)
* [`debug`](#debug)
* [`devel`](#devel)
* [`dry_run`](#dry_run)
* [`env`](#env)
* [`install`](#install)
* [`key_file`](#key_file)
* [`keyring`](#keyring)
* [`home`](#home)
* [`host`](#host)
* [`kube_context`](#kube_context)
* [`recreate_pods`](#recreate_pods)
* [`reset_values`](#reset_values)
* [`reuse_values`](#reuse_values)
* [`no_hooks#`](#no_hooks#)
* [`path`](#path)
* [`purge`](#purge)
* [`release_name`](#release_name)
* [`repo`](#repo)
* [`set`](#set)
* [`timeout`](#timeout)
* [`tiller_namespace`](#tiller_namespace)
* [`tls`](#tls)
* [`tls_ca_cert`](#tls_ca_cert)
* [`tls_cert`](#tls_cert)
* [`tls_key`](#tls_key)
* [`tls_verify`](#tls_verify)
* [`values`](#values)
* [`verify`](#verify)
* [`version`](#version)
* [`wait`](#wait)
* [`chart`](#chart)
* [`namespace`](#namespace)
* [`no_hooks`](#no_hooks)

##### <a name="ensure"></a>`ensure`

Data type: `String`

Specifies whether a chart must be updated.
Valid values are 'present', 'absent'.

Default value: `present`

##### <a name="ca_file"></a>`ca_file`

Data type: `Optional[String]`

Verifies the certificates of the HTTPS-enabled servers using the CA bundle.

Default value: ``undef``

##### <a name="cert_file"></a>`cert_file`

Data type: `Optional[String]`

Identifies the HTTPS client using this SSL certificate file.

Default value: ``undef``

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable verbose output.
Values `true`, `false`.

Default value: ``false``

##### <a name="devel"></a>`devel`

Data type: `Boolean`

Specifies whether to use development versions.
Values `true`, `false`.

Default value: ``false``

##### <a name="dry_run"></a>`dry_run`

Data type: `Boolean`

Specifies whether to simulate a chart update.
Values `true`, `false`.

Default value: ``false``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables for Helm to connect to the kubernetes cluster.

Default value: ``undef``

##### <a name="install"></a>`install`

Data type: `Boolean`

If a release by this name doesn't already exist, run an install

Default value: ``true``

##### <a name="key_file"></a>`key_file`

Data type: `Optional[String]`

Identifies the HTTPS client using the SSL key file.

Default value: ``undef``

##### <a name="keyring"></a>`keyring`

Data type: `Optional[String]`

Location of the public keys that are used for verification.

Default value: ``undef``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

Location of your Helm config. This value overrides `$HELM_HOME`.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

Address of Tiller. This value overrides `$HELM_HOST`.

Default value: ``undef``

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

Name of the kubeconfig context.

Default value: ``undef``

##### <a name="recreate_pods"></a>`recreate_pods`

Data type: `Optional[String]`

Performs pods restart for the resource if applicable

Default value: ``undef``

##### <a name="reset_values"></a>`reset_values`

Data type: `Optional[String]`

When upgrading, reset the values to the ones built into the chart

Default value: ``undef``

##### <a name="reuse_values"></a>`reuse_values`

Data type: `Optional[String]`

when upgrading, reuse the last release's values, and merge in any new values. If '--reset-values' is specified, this is ignored.

Default value: ``undef``

##### <a name="no_hooks#"></a>`no_hooks#`

@param
Specifies whether to prevent hooks running during the installation.
Values `true`, `false`.

##### <a name="path"></a>`path`

Data type: `Array`

The PATH variable used for exec types.

Default value: ``undef``

##### <a name="purge"></a>`purge`

Data type: `Boolean`

Specifies whether to remove the release from the store, and make its name available for later use.
Values `true`, `false`.

Default value: ``true``

##### <a name="release_name"></a>`release_name`

Data type: `Optional[String]`

**Required.** The release name.

Default value: ``undef``

##### <a name="repo"></a>`repo`

Data type: `Optional[String]`

The repository URL for a requested chart.

Default value: ``undef``

##### <a name="set"></a>`set`

Data type: `Optional[Array]`

The set array of values for the `helm create` command.

Default value: `[]`

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer]`

The timeout in seconds to wait for a Kubernetes operation.

Default value: ``undef``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `String`

The Tiller namespace.

Default value: `'kube-system'`

##### <a name="tls"></a>`tls`

Data type: `Boolean`

Specifies whether to enable TLS.
Values `true`, `false`.

Default value: ``false``

##### <a name="tls_ca_cert"></a>`tls_ca_cert`

Data type: `Optional[String]`

The path to TLS CA certificate file.

Default value: ``undef``

##### <a name="tls_cert"></a>`tls_cert`

Data type: `Optional[String]`

The path to TLS certificate file.

Default value: ``undef``

##### <a name="tls_key"></a>`tls_key`

Data type: `Optional[String]`

The path to TLS key file.

Default value: ``undef``

##### <a name="tls_verify"></a>`tls_verify`

Data type: `Boolean`

Enable TLS for request and verify remote.

Default value: ``false``

##### <a name="values"></a>`values`

Data type: `Optional[Array]`

Specify values from a YAML file. Multiple values in an array are accepted.

Default value: `[]`

##### <a name="verify"></a>`verify`

Data type: `Boolean`

Specifies whether to verify the package before installing it.
Values `true`, `false`.

Default value: ``false``

##### <a name="version"></a>`version`

Data type: `Optional[String]`

Specify the version of the chart to install. `undef` installs the latest version.

Default value: ``undef``

##### <a name="wait"></a>`wait`

Data type: `Boolean`

Before marking the release as successful, specify whether to wait until all the pods, PVCs, services, and the minimum number of deployment pods are in a ready state. The `timeout` value determines the duration.
Values `true`, `false`.

Default value: ``false``

##### <a name="chart"></a>`chart`

Data type: `Optional[String]`

The file system location of the package.

Default value: ``undef``

##### <a name="namespace"></a>`namespace`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="no_hooks"></a>`no_hooks`

Data type: `Boolean`



Default value: ``false``

### <a name="helmcreate"></a>`helm::create`

Defined Type helm::chart::create

#### Parameters

The following parameters are available in the `helm::create` defined type:

* [`chart_name`](#chart_name)
* [`chart_path`](#chart_path)
* [`debug`](#debug)
* [`env`](#env)
* [`home`](#home)
* [`host`](#host)
* [`kube_context`](#kube_context)
* [`path`](#path)
* [`starter`](#starter)
* [`tiller_namespace`](#tiller_namespace)

##### <a name="chart_name"></a>`chart_name`

Data type: `Optional[String]`

The name of the Helm chart.
Defaults to `undef`.

Default value: ``undef``

##### <a name="chart_path"></a>`chart_path`

Data type: `Optional[String]`

The location of the Helm chart.
If the directory in the path does not exist, Helm attempts to create it. If the directory and the files already exist, only the conflicting files are overwritten.

Default value: ``undef``

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable verbose output.
Values `true`, `false`.

Default value: ``false``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables for Helm to connect to the Kubernetes cluster.

Default value: ``undef``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

The location of your Helm configuration. This value overrides `$HELM_HOME`.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

Address of Tiller. This value overrides `$HELM_HOST`.

Default value: ``undef``

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

The name of the kubeconfig context.

Default value: ``undef``

##### <a name="path"></a>`path`

Data type: `Optional[Array]`

The PATH variable used for exec types.

Default value: ``undef``

##### <a name="starter"></a>`starter`

Data type: `Optional[String]`

Value for the starter chart.

Default value: ``undef``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `Optional[String]`

Namespace of Tiller.

Default value: ``undef``

### <a name="helmhelm_init"></a>`helm::helm_init`

Defined Type helm::helm_init

#### Parameters

The following parameters are available in the `helm::helm_init` defined type:

* [`init`](#init)
* [`canary_image`](#canary_image)
* [`client_only`](#client_only)
* [`debug`](#debug)
* [`dry_run`](#dry_run)
* [`env`](#env)
* [`home`](#home)
* [`host`](#host)
* [`kube_context`](#kube_context)
* [`local_repo_url`](#local_repo_url)
* [`net_host`](#net_host)
* [`path`](#path)
* [`service_account`](#service_account)
* [`skip_refresh`](#skip_refresh)
* [`stable_repo_url`](#stable_repo_url)
* [`tiller_image`](#tiller_image)
* [`tiller_namespace`](#tiller_namespace)
* [`tiller_tls`](#tiller_tls)
* [`tiller_tls_cert`](#tiller_tls_cert)
* [`tiller_tls_key`](#tiller_tls_key)
* [`tiller_tls_verify`](#tiller_tls_verify)
* [`tls_ca_cert`](#tls_ca_cert)
* [`upgrade`](#upgrade)
* [`overrides`](#overrides)
* [`node_selectors`](#node_selectors)

##### <a name="init"></a>`init`

Data type: `Boolean`

Specifies whether to deploy the tiller pod and initialise the Helm client.
Valid values are `true`, `false`.

Default value: ``true``

##### <a name="canary_image"></a>`canary_image`

Data type: `Boolean`

Specifies whether to use the canary Tiller image.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="client_only"></a>`client_only`

Data type: `Boolean`

Specifies whether to deploy Tiller.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable the verbose output.
Values `true`, `false`.

Default value: ``false``

##### <a name="dry_run"></a>`dry_run`

Data type: `Boolean`

Specifies whether to simulate an installation or delete of a deployment.
Values `true`, `false`.

Default value: ``false``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables required for Helm to connect to the kubernetes cluster.

Default value: ``undef``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

The location for your Helm configuration. This value overrides `$HELM_HOME`.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

The host address for Tiller. Overrides `$HELM_HOST`.

Default value: ``undef``

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

The name for the kubeconfig context to use.

Default value: ``undef``

##### <a name="local_repo_url"></a>`local_repo_url`

Data type: `Optional[String]`

The local repository URL.

Default value: ``undef``

##### <a name="net_host"></a>`net_host`

Data type: `Boolean`

Specifies whether to install Tiller with `net=host`.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="path"></a>`path`

Data type: `Optional[Array]`

The PATH variable used for exec types.

Default value: ``undef``

##### <a name="service_account"></a>`service_account`

Data type: `Optional[String]`

The name for the service account used for deploying Tiller.

Default value: ``undef``

##### <a name="skip_refresh"></a>`skip_refresh`

Data type: `Boolean`

Specifies whether to refresh or download the local repository cache.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="stable_repo_url"></a>`stable_repo_url`

Data type: `Optional[String]`

The stable repository URL.

Default value: ``undef``

##### <a name="tiller_image"></a>`tiller_image`

Data type: `Optional[String]`

Override the Tiller image.

Default value: ``undef``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `String`

Namespace for Tiller.

Default value: `'kube-system'`

##### <a name="tiller_tls"></a>`tiller_tls`

Data type: `Boolean`

Specifies whether to install Tiller with TLS enabled.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="tiller_tls_cert"></a>`tiller_tls_cert`

Data type: `Optional[String]`

The path to the TLS certificate file that is installed with Tiller.

Default value: ``undef``

##### <a name="tiller_tls_key"></a>`tiller_tls_key`

Data type: `Optional[String]`

The path to the TLS key file that is installed with Tiller.

Default value: ``undef``

##### <a name="tiller_tls_verify"></a>`tiller_tls_verify`

Data type: `Boolean`

Specifies whether to install Tiller with TLS enabled and to verify remote certificates.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="tls_ca_cert"></a>`tls_ca_cert`

Data type: `Optional[String]`

Specifies whether to use the path to the CA root certificate.
Valid values are `true`, `false`.

Default value: ``undef``

##### <a name="upgrade"></a>`upgrade`

Data type: `Boolean`

Specifies whether to upgrade if Tiller is installed.
Valid values are `true`, `false`.

Default value: ``false``

##### <a name="overrides"></a>`overrides`

Data type: `Optional[Array]`



Default value: ``undef``

##### <a name="node_selectors"></a>`node_selectors`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="helmpackage"></a>`helm::package`

Defined Type helm::package

#### Parameters

The following parameters are available in the `helm::package` defined type:

* [`chart_name`](#chart_name)
* [`chart_path`](#chart_path)
* [`debug`](#debug)
* [`home`](#home)
* [``host``](#`host`)
* [`kube_context`](#kube_context)
* [`save`](#save)
* [`sign`](#sign)
* [`tiller_namespace`](#tiller_namespace)
* [`version`](#version)
* [`dependency_update`](#dependency_update)
* [`destination`](#destination)
* [`env`](#env)
* [`key`](#key)
* [`keystring`](#keystring)
* [`host`](#host)
* [`path`](#path)

##### <a name="chart_name"></a>`chart_name`

Data type: `Optional[String]`

Defaults to `undef`.
The name of the Helm chart.

Default value: ``undef``

##### <a name="chart_path"></a>`chart_path`

Data type: `Optional[String]`

The file system location of the chart.

Default value: ``undef``

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable verbose output.
Values `true`, `false`.
Defaults to `false`.

Default value: ``false``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

Location of your Helm config. This value overrides `$HELM_HOME`.
Defaults to `undef`.

Default value: ``undef``

##### <a name="`host`"></a>``host``

The address for Tiller. This value overrides `$HELM_HOST`.
Defaults to `undef`.

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

The name for the kubeconfig context.
Defaults to `undef`.

Default value: ``undef``

##### <a name="save"></a>`save`

Data type: `Boolean`

Specifies whether to save the packaged chart to the local chart repository.
Valid values are `true`, `false`.
Defaults to `true`.

Default value: ``true``

##### <a name="sign"></a>`sign`

Data type: `Boolean`

Specifies whether to use a PGP private key to sign the package.
Valid values are `true`, `false`.
Defaults to `false`.

Default value: ``false``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `Optional[String]`

The namespace for Tiller.
Defaults to `undef`.

Default value: ``undef``

##### <a name="version"></a>`version`

Data type: `Optional[String]`

The version of the chart.
Defaults to `undef`.

Default value: ``undef``

##### <a name="dependency_update"></a>`dependency_update`

Data type: `Boolean`

Specifies whether to update dependencies.
Valid values are `true`, `false`.
Defaults to `false`.

Default value: ``false``

##### <a name="destination"></a>`destination`

Data type: `Optional[String]`

The destination location to write to.
Defaults to `undef`.

Default value: ``undef``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables required for Helm to connect to the kubernetes cluster.
 Defaults to `undef`.

Default value: ``undef``

##### <a name="key"></a>`key`

Data type: `Optional[String]`

Specify the key to use.
Defaults to `undef`.

Default value: ``undef``

##### <a name="keystring"></a>`keystring`

Data type: `Optional[String]`

The location of the public keys that are used for verification.
Defaults to `undef`.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="path"></a>`path`

Data type: `Optional[Array]`



Default value: ``undef``

### <a name="helmrepo"></a>`helm::repo`

Defined Type helm::repo

#### Parameters

The following parameters are available in the `helm::repo` defined type:

* [`ensure`](#ensure)
* [`ca_file`](#ca_file)
* [`cert_file`](#cert_file)
* [`debug`](#debug)
* [`env`](#env)
* [`key_file`](#key_file)
* [`no_update`](#no_update)
* [`home`](#home)
* [`host`](#host)
* [`kube_context`](#kube_context)
* [`path`](#path)
* [`tiller_namespace`](#tiller_namespace)
* [`username`](#username)
* [`password`](#password)
* [`repo_name`](#repo_name)
* [`url`](#url)

##### <a name="ensure"></a>`ensure`

Data type: `String`

Specifies whether a repo is added.
Valid values are 'present', 'absent'.

Default value: `present`

##### <a name="ca_file"></a>`ca_file`

Data type: `Optional[String]`

Verify the certificates of HTTPS-enabled servers that are using the current CA bundle.

Default value: ``undef``

##### <a name="cert_file"></a>`cert_file`

Data type: `Optional[String]`

Use the SSL certificate file to identify the HTTPS client.

Default value: ``undef``

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable verbose output.
Values true, false.

Default value: ``false``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables required for Helm to connect to the kubernetes cluster.

Default value: ``undef``

##### <a name="key_file"></a>`key_file`

Data type: `Optional[String]`

Use the SSL key file to identify the HTTPS client.

Default value: ``undef``

##### <a name="no_update"></a>`no_update`

Data type: `Boolean`

Specifies whether to create an error when the repository is already registered.
Values true, false.

Default value: ``false``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

Location of your Helm config. This value overrrides $HELM_HOME.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

The address for Tiller. This value overrides $HELM_HOST.

Default value: ``undef``

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

The name for the kubeconfig context to use.

Default value: ``undef``

##### <a name="path"></a>`path`

Data type: `Optional[Array]`

The PATH variable used for exec types.

Default value: ``undef``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `Optional[String]`

The namespace for Tiller.

Default value: ``undef``

##### <a name="username"></a>`username`

Data type: `Optional[String]`

The username for the remote repository

Default value: ``undef``

##### <a name="password"></a>`password`

Data type: `Optional[String]`

The password for the remote repository.

Default value: ``undef``

##### <a name="repo_name"></a>`repo_name`

Data type: `Optional[String]`

The name for the remote repository.

Default value: ``undef``

##### <a name="url"></a>`url`

Data type: `Optional[String]`

The URL for the remote repository.

Default value: ``undef``

### <a name="helmrepo_update"></a>`helm::repo_update`

Defined Type helm::repo_update

#### Parameters

The following parameters are available in the `helm::repo_update` defined type:

* [`debug`](#debug)
* [`env`](#env)
* [`home`](#home)
* [`host`](#host)
* [`kube_context`](#kube_context)
* [`path`](#path)
* [`tiller_namespace`](#tiller_namespace)
* [`update`](#update)

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Specifies whether to enable verbose output.
Values true, false.

Default value: ``false``

##### <a name="env"></a>`env`

Data type: `Optional[Array]`

Sets the environment variables required for Helm to connect to the Kubernetes cluster.

Default value: ``undef``

##### <a name="home"></a>`home`

Data type: `Optional[String]`

The location of your Helm config. This value overrides $HELM_HOME.

Default value: ``undef``

##### <a name="host"></a>`host`

Data type: `Optional[String]`

The address for Tiller. This value overrides $HELM_HOST.

Default value: ``undef``

##### <a name="kube_context"></a>`kube_context`

Data type: `Optional[String]`

The name for the kubeconfig context to use.

Default value: ``undef``

##### <a name="path"></a>`path`

Data type: `Optional[Array]`

The PATH variable used for exec types.

Default value: ``undef``

##### <a name="tiller_namespace"></a>`tiller_namespace`

Data type: `Optional[String]`

The namespace for Tiller.

Default value: ``undef``

##### <a name="update"></a>`update`

Data type: `Boolean`

Specifies whether the repository is updated.
Values true, false.

Default value: ``true``

## Functions

### <a name="helm_chart_update_flags"></a>`helm_chart_update_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm install chart flags

#### `helm_chart_update_flags()`

Transforms a hash into a string of helm install chart flags

Returns: `Any`

### <a name="helm_create_flags"></a>`helm_create_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm create flags

#### `helm_create_flags()`

Transforms a hash into a string of helm create flags

Returns: `Any`

### <a name="helm_delete_flags"></a>`helm_delete_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm delete flags

#### `helm_delete_flags()`

Transforms a hash into a string of helm delete flags

Returns: `Any`

### <a name="helm_init_flags"></a>`helm_init_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm init flags

#### `helm_init_flags()`

Transforms a hash into a string of helm init flags

Returns: `Any`

### <a name="helm_install_flags"></a>`helm_install_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm install chart flags

#### `helm_install_flags()`

Transforms a hash into a string of helm install chart flags

Returns: `Any`

### <a name="helm_ls_flags"></a>`helm_ls_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm ls flags

#### `helm_ls_flags()`

Transforms a hash into a string of helm ls flags

Returns: `Any`

### <a name="helm_package_flags"></a>`helm_package_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm package flags

#### `helm_package_flags()`

Transforms a hash into a string of helm package flags

Returns: `Any`

### <a name="helm_repo_add_flags"></a>`helm_repo_add_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm repo add flags

#### `helm_repo_add_flags()`

Transforms a hash into a string of helm repo add flags

Returns: `Any`

### <a name="helm_repo_remove_flags"></a>`helm_repo_remove_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm repo remove flags

#### `helm_repo_remove_flags()`

Transforms a hash into a string of helm repo remove flags

Returns: `Any`

### <a name="helm_repo_update_flags"></a>`helm_repo_update_flags`

Type: Ruby 3.x API

Transforms a hash into a string of helm repo update flags

#### `helm_repo_update_flags()`

Transforms a hash into a string of helm repo update flags

Returns: `Any`

## Plans

### <a name="helmprovision_cluster"></a>`helm::provision_cluster`

Provisions machines for integration testing

#### Examples

##### 

```puppet
helm::provision_cluster
```

#### Parameters

The following parameters are available in the `helm::provision_cluster` plan:

* [`image_type`](#image_type)
* [`provision_type`](#provision_type)

##### <a name="image_type"></a>`image_type`

Data type: `Optional[String]`



Default value: `'centos-7'`

##### <a name="provision_type"></a>`provision_type`

Data type: `Optional[String]`



Default value: `'provision_service'`

### <a name="helmpuppetserver_setup"></a>`helm::puppetserver_setup`

Puppet Server Setup

#### Examples

##### 

```puppet
helm::puppetserver_setup
```

#### Parameters

The following parameters are available in the `helm::puppetserver_setup` plan:

* [`collection`](#collection)

##### <a name="collection"></a>`collection`

Data type: `Optional[String]`



Default value: `'puppet7-nightly'`

